XACT: Model based design for developers
#######################################

Xact is a tool for configuring and deploying software intensive systems,
from simulations running on cloud infrastructure to distributed intelligent
sensing systems running on edge devices.

Xact defines a unified configuration data structure for specifying component
dependencies and for configuring various types of messaging middleware,
enabling distributed dataflow systems to be rapidly and conveniently
described and deployed.

It is intended to support model based systems and software engineering
processes and to be a foundation for future design automation tools.
